"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("fs");
class FilePath {
    constructor(filePath) {
        Object.defineProperty(this, "name", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "folder", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "extension", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "root", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        if (!(0, path_1.isAbsolute)(filePath)) {
            filePath = (0, path_1.resolve)(filePath);
        }
        const stat = (0, fs_1.statSync)(filePath);
        if (!stat?.isFile()) {
            throw new Error("The path is not pointing to a file: " + filePath);
        }
        const parts = filePath.split(path_1.sep);
        const fullName = parts.pop() || "";
        const index = fullName.indexOf(".");
        if (index === -1) {
            this.name = fullName;
            this.extension = "";
        }
        else {
            this.name = fullName.substring(0, index);
            this.extension = fullName.substring(index + 1);
        }
        this.folder = parts.pop() || "";
        this.root = parts.join(path_1.sep);
    }
    get fullName() {
        if (this.extension === "") {
            return this.name;
        }
        return this.name + "." + this.extension;
    }
    get fullPath() {
        return this.root + path_1.sep + this.folder + path_1.sep + this.fullName;
    }
}
exports.default = FilePath;
